SelectV2

Trait SelectV2 

pub trait SelectV2<C, R, T>
where C: Connection<R>, R: Row,
{ // Required methods fn select(&self, conn: &mut C) -> Result<Vec<T>>; fn select_with_filter<F>(&self, conn: &mut C, filter: &F) -> Result<Vec<T>> where F: FlavoredFilter; fn select_with_filter_order<F, O>( &self, conn: &mut C, filter: &F, order: &O, ) -> Result<Vec<T>> where F: FlavoredFilter, O: FlavoredOrder; fn select_with_filter_order_limit_offset<F, O>( &self, conn: &mut C, filter: &F, order: &O, limit: usize, offset: usize, ) -> Result<Vec<T>> where F: FlavoredFilter, O: FlavoredOrder; }

Required Methods

fn select(&self, conn: &mut C) -> Result<Vec<T>>

Retrieve the list of items of the type T stored in database

fn select_with_filter<F>(&self, conn: &mut C, filter: &F) -> Result<Vec<T>>
where F: FlavoredFilter,

Retrieve the list of items of the type T stored in database matching the filtering criteria

fn select_with_filter_order<F, O>( &self, conn: &mut C, filter: &F, order: &O, ) -> Result<Vec<T>>

Retrieve the list of items of the type T stored in database matching the filtering criteria

fn select_with_filter_order_limit_offset<F, O>( &self, conn: &mut C, filter: &F, order: &O, limit: usize, offset: usize, ) -> Result<Vec<T>>

Retrieve the list of items of the type T stored in database

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<C, R, T, S> Select<C, R, T> for S